print.oaii_models_df: print S3 method for oaii_models_df class
Description
print prints its argument and returns it invisibly (via
invisible(x)). It is a generic function which means that
new printing methods can be easily added for new classes.
Usage
# S3 method for oaii_models_df
print(x, ...)
Arguments
- x
an object used to select a method.
- ...
further arguments passed to or from other methods.